@@ -26,6 +26,7 @@
 
 #include <QPalette>
 #include <QColor>
+#include <QDBusConnection>
 
 #include <KpkReviewChanges.h>
 #include <KpkStrings.h>
@@ -51,7 +52,8 @@ KpkAddRm::KpkAddRm(QWidget *parent)
     gridLayout_2->addWidget(toolBar = new QToolBar);
     toolBar->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
 
-    Client::instance()->setLocale(KGlobal::locale()->language() + '.' + KGlobal::locale()->encoding());
+    QString locale(KGlobal::locale()->language() + '.' + KGlobal::locale()->encoding());
+    Client::instance()->setHints("locale=" + locale);
 
     // Create a new daemon
     m_client = Client::instance();
@@ -62,7 +64,7 @@ KpkAddRm::KpkAddRm(QWidget *parent)
     packageView->viewport()->setAttribute(Qt::WA_Hover);
 
     // check to see if the backend support these actions
-    m_actions = m_client->getActions();
+    m_actions = m_client->actions();
     // Connect this signal anyway so users that have backend that
     // do not support install or remove can be informed properly
     connect(m_pkg_model_main, SIGNAL(dataChanged(const QModelIndex, const QModelIndex)),
@@ -114,10 +116,10 @@ KpkAddRm::KpkAddRm(QWidget *parent)
     groupsCB->setModel(m_groupsModel);
 
     //initialize the groups
-    Client::Groups groups = m_client->getGroups();
-    // Add All packages entry
+    Client::Groups groups = m_client->groups();
+    // Add Text search entry
     QStandardItem *groupItem;
-    m_groupsModel->appendRow(groupItem = new QStandardItem(i18n("All packages")));
+    m_groupsModel->appendRow(groupItem = new QStandardItem(i18n("Text search")));
     groupItem->setData(AllPackages, Qt::UserRole);
 
     m_groupsModel->appendRow(listOfChangesItem = new QStandardItem(i18n("List of changes")));
@@ -146,7 +148,7 @@ KpkAddRm::KpkAddRm(QWidget *parent)
     }
 
     // install the backend filters
-    filterMenu(m_client->getFilters());
+    filterMenu(m_client->filters());
     filtersTB->setIcon(m_filterIcon);
 
     // set focus on the search lineEdit
@@ -257,12 +259,18 @@ KpkAddRm::~KpkAddRm()
     KConfigGroup filterMenuGroup(&config, "FilterMenu");
 
     kDebug() << "Saving settings";
-    // For usability we will only save ViewInGroups settings,
+    // For usability we will only save ViewInGroups settings and Newest filter,
     // - The user might get angry when he does not find any packages because he didn't
     //   see that a filter is set by config
 
     // This entry does not depend on the backend it's ok to call this pointer
     filterMenuGroup.writeEntry("ViewInGroups", m_actionViewInGroups->isChecked());
+
+    // This entry does not depend on the backend it's ok to call this pointer
+    if (m_client->filters() & Client::FilterNewest) {
+        filterMenuGroup.writeEntry("FilterNewest",
+                                   (bool) filters() & Client::FilterNewest);
+    }
 }
 
 void KpkAddRm::on_actionFindName_triggered()
@@ -369,7 +377,10 @@ void KpkAddRm::search()
         }
     }
 
-    if (m_pkClient_main) {
+    if (m_pkClient_main->error()) {
+        KMessageBox::sorry(this, KpkStrings::daemonError(m_pkClient_main->error()));
+        setCurrentActionEnabled(true);
+    } else {
         setCurrentActionCancel(true);
         connectTransaction(m_pkClient_main);
         transactionBar->addTransaction(m_pkClient_main);
@@ -378,9 +389,6 @@ void KpkAddRm::search()
         // cleans the models
         m_pkg_model_main->clear();
         m_mTransRuning = true;
-    } else {
-        kWarning() << "Search didn't work";
-        setCurrentActionEnabled(true);
     }
 }
 
@@ -392,11 +400,15 @@ void KpkAddRm::connectTransaction(Transaction *transaction)
             this, SLOT(finished(PackageKit::Transaction::ExitStatus, uint)));
     connect(transaction, SIGNAL(errorCode(PackageKit::Client::ErrorType, const QString &)),
             this, SLOT(errorCode(PackageKit::Client::ErrorType, const QString &)));
-    connect(transaction, SIGNAL(allowCancelChanged(bool)),
-            this, SLOT(setCurrentActionEnabled(bool)));
     setCurrentActionEnabled(transaction->allowCancel());
 }
 
+void KpkAddRm::changed()
+{
+    Transaction *trans = qobject_cast<Transaction*>(sender());
+    setCurrentActionEnabled(trans->allowCancel());
+}
+
 void KpkAddRm::message(PackageKit::Client::MessageType message, const QString &details)
 {
     qDebug() << "Error code: " << message << " two: " << details;
@@ -667,6 +679,7 @@ void KpkAddRm::filterMenu(Client::Filters filters)
         m_filtersQM->addSeparator();
         QAction *newest = new QAction(i18n("Only newest packages"), m_filtersQM);
         newest->setCheckable(true);
+        newest->setChecked(filterMenuGroup.readEntry("FilterNewest", true));
         newest->setToolTip( i18n("Only show the newest available package") );
         m_filtersAction[newest] = Client::FilterNewest;
         m_filtersQM->addAction(newest);
