@@ -26,26 +26,21 @@
 #include <KStandardDirs>
 #include <KConfig>
 #include <KConfigGroup>
+#include <KCModuleInfo>
 #include <KDebug>
 #include <QStringList>
-#include <KCModuleInfo>
+#include <QDBusConnection>
+#include <QDBusReply>
 
-#include "KpkInstallFiles.h"
-#include "KpkInstallMimeType.h"
-#include "KpkInstallPackageName.h"
-#include "KpkInstallProvideFile.h"
-#include "KpkRemovePackageByFile.h"
 #include "KpkBackendDetails.h"
 
-namespace kpackagekit {
+using namespace kpackagekit;
 
 KPackageKit::KPackageKit()
  : KUniqueApplication(),
    m_pkUi(0),
    m_running(0)
 {
-    Client::instance()->setLocale(KGlobal::locale()->language() + '.' + KGlobal::locale()->encoding());
-
     setQuitOnLastWindowClosed(false);
 }
 
@@ -66,9 +61,6 @@ void KPackageKit::kcmFinished()
     // kcm is finished we set to 0 to be able to quit
     m_pkUi->deleteLater();
     m_pkUi = 0;
-//     m_addrmPWI = 0;
-//     m_updatePWI = 0;
-//     m_settingsPWI = 0;
     appClose();
 }
 
@@ -85,62 +77,47 @@ int KPackageKit::newInstance()
     bool notSet = true;
     if (args->count()) {
         // grab the list of files
-        KUrl::List urls;
+        QStringList urls;
         for (int i = 0; i < args->count(); i++) {
-            urls << args->url(i);
+            urls << args->url(i).url();
         }
-        KpkInstallFiles *helper = new KpkInstallFiles(urls, this);
-        connect(helper, SIGNAL(close()), this, SLOT(decreaseAndKillRunning()));
-        QTimer::singleShot(0, helper, SLOT(start()));
-        m_running++;
+
+        // TODO remote files are copied to /tmp
+        // what will happen if we call the other process to
+        // install and this very one closes? will the files
+        // in /tmp be deleted?
+        invoke("InstallPackageFiles" , urls);
         notSet = false;
     }
 
     if (args->isSet("updates")) {
         kDebug() << "SHOW UPDATES!";
-        showUpdates();
+        QTimer::singleShot(0, this, SLOT(showUpdates()));
         notSet = false;
     }
     if (args->isSet("settings")) {
         kDebug() << "SHOW SETTINGS!";
-        showSettings();
+        QTimer::singleShot(0, this, SLOT(showSettings()));
         notSet = false;
     }
 
     if (args->isSet("install-mime-type")) {
-        kDebug() << "install-mime-type!" << args->getOptionList("install-mime-type");
-        KpkInstallMimeType *helper;
-        helper = new KpkInstallMimeType(args->getOptionList("install-mime-type"), this);
-        connect(helper, SIGNAL(close()), this, SLOT(decreaseAndKillRunning()));
-        QTimer::singleShot(0, helper, SLOT(start()));
-        m_running++;
+        invoke("InstallMimeTypes" , args->getOptionList("install-mime-type"));
         notSet = false;
     }
 
     if (args->isSet("install-package-name")) {
-        KpkInstallPackageName *helper;
-        helper = new KpkInstallPackageName(args->getOptionList("install-package-name"), this);
-        connect(helper, SIGNAL(close()), this, SLOT(decreaseAndKillRunning()));
-        QTimer::singleShot(0, helper, SLOT(start()));
-        m_running++;
+        invoke("InstallPackageNames" , args->getOptionList("install-package-name"));
         notSet = false;
     }
 
     if (args->isSet("install-provide-file")) {
-        KpkInstallProvideFile *helper;
-        helper = new KpkInstallProvideFile(args->getOptionList("install-provide-file"), this);
-        connect(helper, SIGNAL(close()), this, SLOT(decreaseAndKillRunning()));
-        QTimer::singleShot(0, helper, SLOT(start()));
-        m_running++;
+        invoke("InstallProvideFiles" , args->getOptionList("install-provide-file"));
         notSet = false;
     }
 
     if (args->isSet("remove-package-by-file")) {
-        KpkRemovePackageByFile *helper;
-        helper = new KpkRemovePackageByFile(args->getOptionList("remove-package-by-file"), this);
-        connect(helper, SIGNAL(close()), this, SLOT(decreaseAndKillRunning()));
-        QTimer::singleShot(0, helper, SLOT(start()));
-        m_running++;
+        invoke("RemovePackageByFiles" , args->getOptionList("remove-package-by-file"));
         notSet = false;
     }
 
@@ -148,14 +125,14 @@ int KPackageKit::newInstance()
         KpkBackendDetails *helper;
         helper = new KpkBackendDetails;
         connect(helper, SIGNAL(finished()), this, SLOT(decreaseAndKillRunning()));
-        helper->show();
+        QTimer::singleShot(0, helper, SLOT(show()));
         m_running++;
         notSet = false;
     }
 
     if (notSet) {
         kDebug() << "SHOW UI!";
-        showUi();
+        QTimer::singleShot(0, this, SLOT(showUi()));
     }
 
     args->clear();
@@ -196,6 +173,22 @@ void KPackageKit::showSettings()
     m_pkUi->activateWindow();
 }
 
+void KPackageKit::invoke(const QString &method_name, const QStringList &args)
+{
+    QDBusMessage message;
+    message = QDBusMessage::createMethodCall("org.freedesktop.PackageKit",
+                                             "/org/freedesktop/PackageKit",
+                                             "org.freedesktop.PackageKit.Modify",
+                                             method_name);
+    message << (uint) 0;
+    message << args;
+    message << QString();
+
+    // This call must block otherwise this application closes before
+    // smarticon is activated
+    QDBusMessage reply = QDBusConnection::sessionBus().call(message, QDBus::Block);
+
+    QTimer::singleShot(0, this, SLOT(appClose()));
 }
 
 #include "KPackageKit.moc"
