@@ -36,22 +36,20 @@ public:
 
     virtual int newInstance();
 
-    void showUi();
-    void showUpdates();
-    void showSettings();
-
 private slots:
     void appClose();
     void kcmFinished();
     void decreaseAndKillRunning();
+    void showUi();
+    void showUpdates();
+    void showSettings();
 
 private:
     KpkMainUi *m_pkUi;
-//     KPageWidgetItem *m_addrmPWI;
-//     KPageWidgetItem *m_updatePWI;
-//     KPageWidgetItem *m_settingsPWI;
+    void invoke(const QString &method_name, const QStringList &args);
 
     int m_running;
+    bool m_init;
 };
 
 }
