@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by Daniel Nicoletti                                *
+ *   Copyright (C) 2008-2009 by Daniel Nicoletti                           *
  *   dantti85-pk@yahoo.com.br                                              *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -24,11 +24,14 @@
 #include <KGenericFactory>
 #include <KStandardDirs>
 #include <KConfigGroup>
-#include <KProtocolManager>
+#include <KDirWatch>
 
 #include <QDateTime>
 #include <QtDBus/QDBusMessage>
 #include <QtDBus/QDBusConnection>
+#include <QtDBus/QDBusReply>
+// <QDBusVariant> reply = QDBusConnection::systemBus().call(message);
+//     QStringList
 
 #include <limits.h>
 #include <solid/networking.h>
@@ -41,15 +44,18 @@ K_PLUGIN_FACTORY(KPackageKitFactory, registerPlugin<KPackageKitD>();)
 K_EXPORT_PLUGIN(KPackageKitFactory("kpackagekitd"))
 
 KPackageKitD::KPackageKitD(QObject *parent, const QList<QVariant> &)
-    : KDEDModule(parent), m_refreshCacheT(0)
+    : KDEDModule(parent)
 {
     m_qtimer = new QTimer(this);
     connect(m_qtimer, SIGNAL(timeout()), this, SLOT(init()));
 
-    // Create a new daemon
-    m_client = Client::instance();
-    connect(m_client, SIGNAL(transactionListChanged(const QList<PackageKit::Transaction*> &)),
-            this, SLOT(transactionListChanged(const QList<PackageKit::Transaction*> &)));
+    // Watch fot TransactionListChanged so we call smart icon
+    QDBusConnection::systemBus().connect("",
+                                         "",
+                                         "org.freedesktop.PackageKit",
+                                         "TransactionListChanged",
+                                         this,
+                                         SLOT(transactionListChanged(const QStringList &)));
 
     // Start after 5 minutes, 360000 msec
     // To keep the startup fast..
@@ -66,7 +72,15 @@ void KPackageKitD::init()
     m_qtimer->disconnect();
     connect(m_qtimer, SIGNAL(timeout()), this, SLOT(read()));
 
-    Client::Actions act = m_client->getActions();
+    QDBusMessage message;
+    message = QDBusMessage::createMethodCall("org.freedesktop.PackageKit",
+                                             "/org/freedesktop/PackageKit",
+                                             "org.freedesktop.DBus.Properties",
+                                             QLatin1String("Get"));
+    message << QLatin1String("org.freedesktop.PackageKit");
+    message << QLatin1String("Roles");
+    QDBusReply<QDBusVariant> reply = QDBusConnection::systemBus().call(message);
+    bool canRefreshCache = reply.value().variant().toString().split(';').contains("refresh-cache");
 
     // check to see when the next check update will happen
     // if more that 15 minutes, call show updates
@@ -75,29 +89,26 @@ void KPackageKitD::init()
     // default to one day, 86400 sec
     uint interval = checkUpdateGroup.readEntry("interval", KpkEnum::TimeIntervalDefault);
 
-    // 1160 -> 15 minutes
-    if (((m_client->getTimeSinceAction(Client::ActionRefreshCache) - interval > 1160) && interval != 0 )
-        || !(act & Client::ActionRefreshCache)) {
+    if (!canRefreshCache) {
+        //if the backend does not suport refreshing cache let's don't do nothing
+        return;
+    } else if ((getTimeSinceRefreshCache() - interval > 1160) && interval != 0 ) {
+        // 1160 -> 15 minutes
         // WE ARE NOT GOING TO REFRESH THE CACHE if it is not the time BUT
         // WE can SHOW the user his system updates :D
         update();
     }
 
-    if (!(act & Client::ActionRefreshCache)) {
-        //if the backend does not suport refreshing cache let's don't do nothing
-        return;
-    }
-
     read();
 
     //check if any changes to the file occour
     //this also prevents from reading when a checkUpdate happens
-    m_confWatch = new KDirWatch(this);
-    m_confWatch->addFile(KStandardDirs::locateLocal("config", "KPackageKit"));
-    connect(m_confWatch, SIGNAL(dirty(const QString &)),   this, SLOT(read()));
-    connect(m_confWatch, SIGNAL(created(const QString &)), this, SLOT(read()));
-    connect(m_confWatch, SIGNAL(deleted(const QString &)), this, SLOT(read()));
-    m_confWatch->startScan();
+    KDirWatch *confWatch = new KDirWatch(this);
+    confWatch->addFile(KStandardDirs::locateLocal("config", "KPackageKit"));
+    connect(confWatch, SIGNAL(  dirty(const QString &)), this, SLOT(read()));
+    connect(confWatch, SIGNAL(created(const QString &)), this, SLOT(read()));
+    connect(confWatch, SIGNAL(deleted(const QString &)), this, SLOT(read()));
+    confWatch->startScan();
 }
 
 void KPackageKitD::read()
@@ -106,12 +117,12 @@ void KPackageKitD::read()
     KConfigGroup checkUpdateGroup( &config, "CheckUpdate" );
     // default to one day, 86400 sec
     int interval = checkUpdateGroup.readEntry("interval", KpkEnum::TimeIntervalDefault);
-    int actRefreshCache = m_client->getTimeSinceAction(Client::ActionRefreshCache);
+    int actRefreshCache = getTimeSinceRefreshCache();
     if (interval == KpkEnum::Never) {
         return;
     }
     if (actRefreshCache >= interval) {
-        checkUpdates();
+        refreshAndUpdate();
     } else {
         //check first to see any overflow...
         if ((interval - actRefreshCache) > 4294966) {
@@ -122,16 +133,6 @@ void KPackageKitD::read()
     }
 }
 
-void KPackageKitD::finished(PackageKit::Transaction::ExitStatus status, uint)
-{
-    if (status == Transaction::ExitSuccess) {
-        update();
-    } else {
-        // try again in 5 minutes
-        m_qtimer->start(FIVE_MIN);
-    }
-}
-
 bool KPackageKitD::systemIsReady()
 {
     // test whether network is connected
@@ -148,38 +149,7 @@ bool KPackageKitD::systemIsReady()
     return true;
 }
 
-void KPackageKitD::checkUpdates()
-{
-    // check whether system is ready for an updates check
-    if (!systemIsReady()) {
-        m_qtimer->start(FIVE_MIN);
-        return;
-    }
-
-    Client::instance()->setProxy(KProtocolManager::proxyFor("http"), KProtocolManager::proxyFor("ftp"));
-    m_refreshCacheT = m_client->refreshCache(true);
-    if (m_refreshCacheT == 0) {
-        // try again in 5 minutes
-        m_qtimer->start(FIVE_MIN);
-    } else {
-        // If something goes wrong at least kpackagekitSmartIcon
-        // will show the error
-        QDBusMessage message;
-        message = QDBusMessage::createMethodCall("org.kde.KPackageKitSmartIcon",
-                                                    "/",
-                                                    "org.kde.KPackageKitSmartIcon",
-                                                    QLatin1String("WatchTransaction"));
-        message << qVariantFromValue(m_refreshCacheT->tid());
-        QDBusMessage reply = QDBusConnection::sessionBus().call(message);
-        if (reply.type() != QDBusMessage::ReplyMessage) {
-            kWarning() << "Message did not receive a reply";
-        }
-        connect(m_refreshCacheT, SIGNAL(finished(PackageKit::Transaction::ExitStatus, uint)),
-                this, SLOT(finished(PackageKit::Transaction::ExitStatus, uint)));
-    }
-}
-
-void KPackageKitD::transactionListChanged(const QList<PackageKit::Transaction*> &tids)
+void KPackageKitD::transactionListChanged(const QStringList &tids)
 {
     if (tids.size()) {
         QDBusMessage message;
@@ -193,6 +163,20 @@ void KPackageKitD::transactionListChanged(const QList<PackageKit::Transaction*>
     }
 }
 
+void KPackageKitD::refreshAndUpdate()
+{
+    // check whether system is ready for an update
+    if (systemIsReady()) {
+        QDBusMessage message;
+        message = QDBusMessage::createMethodCall("org.kde.KPackageKitSmartIcon",
+                                                 "/",
+                                                 "org.kde.KPackageKitSmartIcon",
+                                                QLatin1String("RefreshAndUpdate"));
+        QDBusConnection::sessionBus().call(message);
+    }
+    m_qtimer->start(FIVE_MIN);
+}
+
 void KPackageKitD::update()
 {
     // check whether system is ready for an update
@@ -205,3 +189,15 @@ void KPackageKitD::update()
         QDBusConnection::sessionBus().call(message);
     }
 }
+
+uint KPackageKitD::getTimeSinceRefreshCache() const
+{
+    QDBusMessage message;
+    message = QDBusMessage::createMethodCall("org.freedesktop.PackageKit",
+                                             "/org/freedesktop/PackageKit",
+                                             "org.freedesktop.PackageKit",
+                                             QLatin1String("GetTimeSinceAction"));
+    message << QLatin1String("refresh-cache");
+    QDBusReply<uint> reply = QDBusConnection::systemBus().call(message);
+    return reply.value();
+}
