@@ -22,11 +22,8 @@
 #define KPACKAGEKITD_H
 
 #include <KDEDModule>
-#include <KDirWatch>
-#include <QTimer>
-#include <QPackageKit>
 
-using namespace PackageKit;
+#include <QTimer>
 
 class KPackageKitD : public KDEDModule
 {
@@ -39,19 +36,16 @@ public:
 private slots:
     void init();
     void read();
-    void checkUpdates();
-    void finished(PackageKit::Transaction::ExitStatus status, uint);
 
-    void transactionListChanged(const QList<PackageKit::Transaction*> &tids);
+    void transactionListChanged(const QStringList &tids);
 
 private:
     void update();
+    void refreshAndUpdate();
+    bool systemIsReady();
+    uint getTimeSinceRefreshCache() const;
 
     QTimer *m_qtimer;
-    KDirWatch *m_confWatch;
-    Client *m_client;
-    Transaction *m_refreshCacheT;
-    bool systemIsReady();
 };
 
 #endif
