@@ -19,11 +19,15 @@
  ***************************************************************************/
 
 #include "KpkModelOrigin.h"
-#include <QVariant>
-#include <QDebug>
 
-KpkModelOrigin::KpkModelOrigin(QObject *parent) :
- QAbstractListModel(parent), m_finished(false)
+#include <KpkStrings.h>
+#include <QVariant>
+
+#include <KDebug>
+#include <KMessageBox>
+
+KpkModelOrigin::KpkModelOrigin(QObject *parent)
+ : QAbstractListModel(parent), m_finished(false)
 {
     m_client = Client::instance();
 }
@@ -35,43 +39,48 @@ KpkModelOrigin::~KpkModelOrigin()
 
 QVariant KpkModelOrigin::data(const QModelIndex &index, int role) const
 {
-     if ( role == Qt::DisplayRole )
-         return m_items.at( index.row() ).value(Qt::DisplayRole);
+    if (role == Qt::DisplayRole) {
+        return m_items.at(index.row()).value(Qt::DisplayRole);
+    }
 
-     if (role == Qt::CheckStateRole)
-         return m_actualState[ m_items.at( index.row() ).value(Qt::UserRole).toString() ];
+    if (role == Qt::CheckStateRole) {
+        return m_actualState[ m_items.at( index.row() ).value(Qt::UserRole).toString() ];
+    }
 
-     return  QVariant();
+    return  QVariant();
 }
 
 Qt::ItemFlags KpkModelOrigin::flags(const QModelIndex &index) const
 {
-    if (!index.isValid())
+    if (!index.isValid()) {
         return Qt::ItemIsEnabled;
-    else
+    } else {
         return Qt::ItemIsUserCheckable | QAbstractItemModel::flags(index);
+    }
 }
 
 void KpkModelOrigin::addOriginItem(const QString &repo_id, const QString &details, bool enabled)
 {
     if (m_finished) {
-	m_items.clear();
-	m_finished = false;
-	layoutChanged();
+        m_items.clear();
+        m_finished = false;
+        layoutChanged();
     }
     beginInsertRows(QModelIndex(), m_items.size(), m_items.size());
     QHash<Qt::ItemDataRole, QVariant> hash;
     hash[Qt::UserRole] = repo_id;
     hash[Qt::DisplayRole] = details;
     if (enabled) {
-	hash[Qt::CheckStateRole] = Qt::Checked;
-	if ( !m_actualState.contains(repo_id) )
-	    m_actualState[repo_id] = Qt::Checked;
+        hash[Qt::CheckStateRole] = Qt::Checked;
+        if (!m_actualState.contains(repo_id)) {
+            m_actualState[repo_id] = Qt::Checked;
+        }
     }
     else {
-	hash[Qt::CheckStateRole] = Qt::Unchecked;
-	if ( !m_actualState.contains(repo_id) )
-	    m_actualState[repo_id] = Qt::Unchecked;
+        hash[Qt::CheckStateRole] = Qt::Unchecked;
+        if (!m_actualState.contains(repo_id)) {
+            m_actualState[repo_id] = Qt::Unchecked;
+        }
     }
     m_items << hash;
     emit stateChanged();
@@ -85,8 +94,10 @@ void KpkModelOrigin::finished()
 
 void KpkModelOrigin::clearChanges()
 {
-    for (int i = 0; i < m_items.size(); i++)
-	m_actualState[ m_items.at(i).value(Qt::UserRole).toString() ] = (Qt::CheckState) m_items.at(i).value(Qt::CheckStateRole).toInt();
+    for (int i = 0; i < m_items.size(); i++) {
+        m_actualState[m_items.at(i).value(Qt::UserRole).toString()]
+            = (Qt::CheckState) m_items.at(i).value(Qt::CheckStateRole).toInt();
+    }
     emit layoutChanged();
 }
 
@@ -104,10 +115,13 @@ bool KpkModelOrigin::save()
 {
     QString repoId;
     for (int i = 0; i < m_items.size(); i++) {
-        if ( m_items.at(i).value(Qt::CheckStateRole) != m_actualState.value( m_items.at(i).value(Qt::UserRole).toString() ) ) {
+        if (m_items.at(i).value(Qt::CheckStateRole) != m_actualState.value(m_items.at(i).value(Qt::UserRole).toString())) {
             repoId = m_items.at(i).value(Qt::UserRole).toString();
-            if ( m_client->repoEnable(repoId, (bool) m_actualState.value( repoId ) ) == 0 )
+            Transaction *t = m_client->repoEnable(repoId, (bool) m_actualState.value(repoId));
+            if (t->error()) {
+                KMessageBox::sorry(0, KpkStrings::daemonError(t->error()));
                 return false;
+            }
         }
     }
     return true;
@@ -115,16 +129,18 @@ bool KpkModelOrigin::save()
 
 bool KpkModelOrigin::setData(const QModelIndex &index, const QVariant &value, int role)
 {
-    if (index.isValid() && role == Qt::CheckStateRole ) {
-	m_actualState[ m_items.at( index.row() ).value(Qt::UserRole).toString() ] = (Qt::CheckState) value.toUInt();
-	emit stateChanged();
+    if (index.isValid() && role == Qt::CheckStateRole) {
+        m_actualState[m_items.at(index.row()).value(Qt::UserRole).toString()]
+            = (Qt::CheckState) value.toUInt();
+        emit stateChanged();
         return true;
-    }
-    else
+    } else {
         return false;
+    }
 }
 
-int KpkModelOrigin::rowCount(const QModelIndex &index) const {
+int KpkModelOrigin::rowCount(const QModelIndex &index) const
+{
     Q_UNUSED(index);
     return m_items.size();
 }
