@@ -39,7 +39,8 @@ KpkDistroUpgrade::~KpkDistroUpgrade()
 void KpkDistroUpgrade::checkDistroUpgrades()
 {
     if (!isRunning()) {
-        if (Transaction *t = Client::instance()->getDistroUpgrades()) {
+        Transaction *t = Client::instance()->getDistroUpgrades();
+        if (!t->error()) {
             connect(t, SIGNAL(distroUpgrade(PackageKit::Client::DistroUpgradeType, const QString &, const QString &)),
                     this, SLOT(distroUpgrade(PackageKit::Client::DistroUpgradeType, const QString &, const QString &)));
             connect(t, SIGNAL(finished(PackageKit::Transaction::ExitStatus, uint)),
@@ -91,7 +92,9 @@ void KpkDistroUpgrade::handleDistroUpgradeAction(uint action)
                     this, SLOT(distroUpgradeError(QProcess::ProcessError)));
             connect (m_distroUpgradeProcess, SIGNAL(finished(int, QProcess::ExitStatus)),
                     this, SLOT(distroUpgradeFinished(int, QProcess::ExitStatus)));
-
+            QStringList env = QProcess::systemEnvironment();
+            env << "DESKTOP=kde";
+            m_distroUpgradeProcess->setEnvironment(env);
             m_distroUpgradeProcess->start("/usr/share/PackageKit/pk-upgrade-distro.sh");
 //             suppressSleep(true);
             break;
