@@ -23,13 +23,14 @@
 #include <KpkStrings.h>
 #include <KpkTransaction.h>
 #include <KpkIcons.h>
+#include <KpkImportance.h>
+#include <KpkEnum.h>
 
 #include <QMenu>
 #include <QTimer>
 #include <QTreeView>
 #include <QStandardItemModel>
 #include <KNotification>
-#include <KProtocolManager>
 #include <KMessageBox>
 #include <KLocale>
 
@@ -38,8 +39,6 @@
 
 #include <KDebug>
 
-#define RESTART_ICON_SIZE 64
-
 Q_DECLARE_METATYPE(Transaction*)
 
 KpkTransactionTrayIcon::KpkTransactionTrayIcon(QObject *parent)
@@ -61,7 +60,7 @@ KpkTransactionTrayIcon::KpkTransactionTrayIcon(QObject *parent)
 
     // Create a new daemon
     m_client = Client::instance();
-    m_act = Client::instance()->getActions();
+    m_act = Client::instance()->actions();
 
     connect(m_client, SIGNAL(transactionListChanged(const QList<PackageKit::Transaction*> &)),
             this, SLOT(transactionListChanged(const QList<PackageKit::Transaction*> &)));
@@ -112,13 +111,11 @@ void KpkTransactionTrayIcon::refreshCache()
 {
     increaseRunning();
     // in this case refreshCache action must be clicked
-    Client::instance()->setProxy(KProtocolManager::proxyFor("http"), KProtocolManager::proxyFor("ftp"));
-    if (Transaction *t = m_client->refreshCache(true)) {
-        createTransactionDialog(t);
+    Transaction *t = m_client->refreshCache(true);
+    if (t->error()) {
+        KMessageBox::sorry(0, KpkStrings::daemonError(t->error()));
     } else {
-        KMessageBox::sorry(m_menu,
-                           i18n("You do not have the necessary privileges to perform this action."),
-                           i18n("Failed to refresh package lists"));
+        createTransactionDialog(t);
     }
     decreaseRunning();
 }
@@ -187,10 +184,10 @@ void KpkTransactionTrayIcon::transactionListChanged(const QList<PackageKit::Tran
             QString toolTip;
             if (m_restartType != Client::RestartNone) {
                 toolTip.append(KpkStrings::restartType(m_restartType) + '\n');
-                toolTip.append(i18np("Package: %1",
-                                     "Packages: %1",
-                                     m_restartPackages.join(", "),
-                                     m_restartPackages.size()));
+                toolTip.append(i18np("Package: %2",
+                                     "Packages: %2",
+                                     m_restartPackages.size(),
+                                     m_restartPackages.join(", ")));
                 m_smartSTI->setIcon(KpkIcons::restartIcon(m_restartType));
             }
             if (m_messages.size()) {
@@ -213,37 +210,90 @@ void KpkTransactionTrayIcon::transactionListChanged(const QList<PackageKit::Tran
 void KpkTransactionTrayIcon::setCurrentTransaction(PackageKit::Transaction *transaction)
 {
     m_currentTransaction = transaction;
-    m_smartSTI->setIcon(KpkIcons::statusIcon(m_currentTransaction->status()));
-    currentProgressChanged(m_currentTransaction->progress());
-    connect(m_currentTransaction, SIGNAL(statusChanged(PackageKit::Transaction::Status)),
-            this, SLOT(currentStatusChanged(PackageKit::Transaction::Status)));
-    connect(m_currentTransaction, SIGNAL(progressChanged(PackageKit::Transaction::ProgressInfo)),
-            this, SLOT(currentProgressChanged(PackageKit::Transaction::ProgressInfo)));
+    // update icon
+    transactionChanged();
+    connect(m_currentTransaction, SIGNAL(changed()),
+            this, SLOT(transactionChanged()));
     connect(m_currentTransaction, SIGNAL(message(PackageKit::Client::MessageType, const QString &)),
             this, SLOT(message(PackageKit::Client::MessageType, const QString &)));
     connect(m_currentTransaction, SIGNAL(requireRestart(PackageKit::Client::RestartType, Package *)),
             this, SLOT(requireRestart(PackageKit::Client::RestartType, Package *)));
+    connect(m_currentTransaction, SIGNAL(finished(PackageKit::Transaction::ExitStatus, uint)),
+            this, SLOT(finished(PackageKit::Transaction::ExitStatus, uint)));
     m_smartSTI->show();
 }
 
-void KpkTransactionTrayIcon::currentProgressChanged(PackageKit::Transaction::ProgressInfo info)
+void KpkTransactionTrayIcon::finished(PackageKit::Transaction::ExitStatus status, uint runtime)
 {
-    QString toolTip;
-    if (info.percentage && info.percentage <= 100) {
-        toolTip = i18n("%1% - %2", info.percentage, KpkStrings::status(m_currentTransaction->status()));
-    } else {
-        toolTip = i18n("%1", KpkStrings::status(m_currentTransaction->status()));
+    Q_UNUSED(status)
+    Q_UNUSED(runtime)
+
+    // check if the transaction emitted any require restart
+    if (m_restartType != Client::RestartNone) {
+        increaseRunning();
+        Client::RestartType type = m_restartType;
+
+        // Create the notification object
+        KNotification *notify = new KNotification("RestartRequired", 0, KNotification::Persistent);
+        QString text("<b>" + i18n("The system update has completed") + "</b>");
+        text.append("<br />" + KpkStrings::restartType(type));
+        m_restartPackages.removeDuplicates();
+        m_restartPackages.sort();
+        if (m_restartPackages.size()) {
+            text.append("<br />Packages: " + m_restartPackages.join(", "));
+        }
+
+        QStringList actions;
+        switch (type) {
+        case Client::RestartSystem :
+        case Client::RestartSecuritySystem :
+            actions << i18nc("Restart the computer", "Restart");
+            actions << i18n("Not now");
+            m_restartAction->setText(i18nc("Restart the computer", "Restart"));
+            break;
+        case Client::RestartSession :
+        case Client::RestartSecuritySession :
+            actions << i18n("Logout");
+            actions << i18n("Not now");
+            m_restartAction->setText(i18n("Logout"));
+            break;
+        case Client::RestartApplication :
+            // What do we do in restart application?
+            // we don't even know what application is
+            // SHOULD we check for pkg and see the installed
+            // files and try to match some running process?
+            break;
+        case Client::RestartNone :
+        case Client::UnknownRestartType :
+            // We do not set a restart type cause it will probably
+            // be already none, if not we will still want that restart type.
+            return;
+        }
+
+        notify->setPixmap(KpkIcons::restartIcon(type).pixmap(KPK_ICON_SIZE, KPK_ICON_SIZE));
+        m_restartAction->setIcon(KpkIcons::restartIcon(type));
+        notify->setText(text);
+        notify->setActions(actions);
+        connect(notify, SIGNAL(activated(uint)),
+                this, SLOT(restartActivated(uint)));
+        connect(notify, SIGNAL(closed()),
+                this, SLOT(decreaseRunning()));
+
+        notify->sendEvent();
+
+        // Reset the restart type
+        m_restartType = Client::RestartNone;
     }
-    m_smartSTI->setToolTip(toolTip);
 }
 
-void KpkTransactionTrayIcon::currentStatusChanged(PackageKit::Transaction::Status status)
+void KpkTransactionTrayIcon::transactionChanged()
 {
+    uint percentage            = m_currentTransaction->percentage();
+    Transaction::Status status = m_currentTransaction->status();
     QString toolTip;
-    PackageKit::Transaction::ProgressInfo info = m_currentTransaction->progress();
 
-    if (info.percentage && info.percentage <= 100) {
-        toolTip = i18n("%1% - %2", info.percentage, KpkStrings::status(status));
+    if (percentage && percentage <= 100) {
+        toolTip = i18n("%1% - %2", percentage, KpkStrings::status(status));
     } else {
         toolTip = i18n("%1", KpkStrings::status(status));
     }
@@ -307,12 +357,11 @@ void KpkTransactionTrayIcon::updateMenu(const QList<PackageKit::Transaction*> &t
         // as it was some times
         transactionAction->setData(t->tid());
 
-        if (t->role().action == Client::ActionRefreshCache) {
+        if (t->role() == Client::ActionRefreshCache) {
             refreshCache = false;
         }
 
-        text = KpkStrings::action(t->role().action)
-               + ' ' + t->role().terms.join(", ")
+        text = KpkStrings::action(t->role())
                + " (" + KpkStrings::status(t->status()) + ')';
         transactionAction->setText(text);
         transactionAction->setIcon(KpkIcons::statusIcon(t->status()));
@@ -348,61 +397,16 @@ void KpkTransactionTrayIcon::activated(QSystemTrayIcon::ActivationReason reason)
 
 void KpkTransactionTrayIcon::requireRestart(PackageKit::Client::RestartType type, Package *pkg)
 {
-    // Check if the type is NOT the most important restart type
-    if (type <= m_restartType) {
-        // we alread have the most important one
-        return;
+    int old = KpkImportance::restartImportance(m_restartType);
+    int newer = KpkImportance::restartImportance(type);
+    // Check to see which one is more important
+    if (newer > old) {
+        m_restartType = type;
     }
 
-    increaseRunning();
-    m_restartPackages << pkg->name();
-
-    KNotification *notify = new KNotification("RestartRequired", 0, KNotification::Persistent);
-    QString text("<b>" + i18n("The system update has completed") + "</b>");
-    text.append("<br />" + KpkStrings::restartType(type));
-    notify->setText(text);
-
-    QStringList actions;
-    switch (type) {
-    case Client::RestartSystem :
-        notify->setPixmap(KpkIcons::restartIcon(type).pixmap(RESTART_ICON_SIZE, RESTART_ICON_SIZE));
-        actions << i18nc("Restart the computer", "Restart");
-        actions << i18n("Not now");
-        m_restartType = Client::RestartSystem;
-        m_restartAction->setIcon(KpkIcons::restartIcon(type));
-        m_restartAction->setText(i18nc("Restart the computer", "Restart"));
-        break;
-    case Client::RestartSession :
-        notify->setPixmap(KpkIcons::restartIcon(type).pixmap(RESTART_ICON_SIZE, RESTART_ICON_SIZE));
-        actions << i18n("Logout");
-        actions << i18n("Not now");
-        if (m_restartType != Client::RestartSystem) {
-            m_restartType = Client::RestartSession;
-        }
-        m_restartAction->setIcon(KpkIcons::restartIcon(type));
-        m_restartAction->setText(i18n("Logout"));
-        break;
-    case Client::RestartApplication :
-        notify->setPixmap(KpkIcons::restartIcon(type).pixmap(RESTART_ICON_SIZE, RESTART_ICON_SIZE));
-        // What do we do in restart application?
-        // we don't even know what application is
-        // SHOULD we check for pkg and see the installed
-        // files and try to match some running process?
-        break;
-    case Client::RestartNone :
-    case Client::UnknownRestartType :
-        // We do not set a restart type cause it will probably
-        // be already none, if not we will still want that restart type.
-        return;
+    if (!pkg->name().isEmpty()) {
+        m_restartPackages << pkg->name();
     }
-
-    notify->setActions(actions);
-    connect(notify, SIGNAL(activated(uint)),
-            this, SLOT(restartActivated(uint)));
-    connect(notify, SIGNAL(closed()),
-            this, SLOT(decreaseRunning()));
-
-    notify->sendEvent();
 }
 
 void KpkTransactionTrayIcon::restartActivated(uint action)
