@@ -39,12 +39,13 @@ public:
     ~KpkUpdateIcon();
 
 signals:
-    void watchTransaction(const QString &tid);
+    void watchTransaction(const QString &tid, bool interactive);
 
 public slots:
-    void checkUpdates();
+    void refreshAndUpdate(bool refresh);
 
 private slots:
+    void update();
     void updateListed(PackageKit::Package*);
     void updateCheckFinished(PackageKit::Transaction::ExitStatus, uint runtime);
     void handleUpdateAction(uint action);
