@@ -22,17 +22,19 @@
 #include "KpkUpdateDetails.h"
 #include "KpkDistroUpgrade.h"
 #include "KpkHistory.h"
+#include "KpkMacros.h"
+
+#include <QDBusConnection>
 
 #include <KpkStrings.h>
 #include <KpkIcons.h>
 #include <KpkTransactionBar.h>
 #include <KpkPackageModel.h>
-#include <KpkSimplePackageModel.h>
+#include <KpkSimulateModel.h>
 #include <KpkDelegate.h>
 #include <KpkRequirements.h>
 
 #include <KMessageBox>
-#include <KProtocolManager>
 #include <KDebug>
 
 #define UNIVERSAL_PADDING 6
@@ -42,13 +44,13 @@ KpkUpdate::KpkUpdate(QWidget *parent)
 {
     setupUi(this);
 
-    m_dependsPkgModel = new KpkSimplePackageModel(this);
     selectAllPB->setIcon(KpkIcons::getIcon("package-update"));
     refreshPB->setIcon(KpkIcons::getIcon("view-refresh"));
     historyPB->setIcon(KpkIcons::getIcon("view-history"));
     transactionBar->setBehaviors(KpkTransactionBar::AutoHide);
 
-    Client::instance()->setLocale(KGlobal::locale()->language() + '.' + KGlobal::locale()->encoding());
+    QString locale(KGlobal::locale()->language() + '.' + KGlobal::locale()->encoding());
+    Client::instance()->setHints("locale=" + locale);
 
     //initialize the model, delegate, client and  connect it's signals
     packageView->setItemDelegate(pkg_delegate = new KpkDelegate(packageView));
@@ -59,9 +61,11 @@ KpkUpdate::KpkUpdate(QWidget *parent)
 
     // Create a new client
     m_client = Client::instance();
+    connect(m_client, SIGNAL(updatesChanged()),
+            this, SLOT(getUpdates()));
 
     // check to see what roles the backend
-    m_actions = m_client->getActions();
+    m_actions = m_client->actions();
 
     // hide distro Upgrade container and line
     distroUpgradesSA->hide();
@@ -101,31 +105,44 @@ void KpkUpdate::on_selectAllPB_clicked()
 
 void KpkUpdate::load()
 {
-    displayUpdates(KpkTransaction::Success);
+    getUpdates();
 }
 
 void KpkUpdate::applyUpdates()
 {
     // If the backend supports getRequires do it
-    if (m_actions & Client::ActionGetRequires) {
+    if (m_actions & Client::ActionSimulateUpdatePackages) {
 
-        PackageKit::Transaction *dependsT;
-        dependsT = m_client->getDepends(m_pkg_model_updates->selectedPackages(), Client::FilterNotInstalled, true);
-        m_dependsPkgModel->clear();
-        connect(dependsT, SIGNAL(package(PackageKit::Package *)),
-                m_dependsPkgModel, SLOT(addPackage(PackageKit::Package *)));
-        connect(dependsT, SIGNAL(finished(PackageKit::Transaction::ExitStatus, uint)),
-                this, SLOT(getDependsFinished(PackageKit::Transaction::ExitStatus, uint)));
-        connect(dependsT, SIGNAL(errorCode(PackageKit::Client::ErrorType, const QString &)),
-                this, SLOT(errorCode(PackageKit::Client::ErrorType, const QString &)));
+        PackageKit::Transaction *t;
+        KpkSimulateModel *simulateModel = new KpkSimulateModel(this);
 
-        // Create a Transaction dialog to don't upset the user
-        QPointer<KpkTransaction> reqFinder = new KpkTransaction(dependsT, KpkTransaction::CloseOnFinish | KpkTransaction::Modal, this);
-        reqFinder->exec();
-        delete reqFinder;
+        t = m_client->simulateUpdatePackages(m_pkg_model_updates->selectedPackages());
+        if (t->error()) {
+                KMessageBox::sorry(this, KpkStrings::daemonError(t->error()));
+        } else {
+                connect(t, SIGNAL(package(PackageKit::Package *)),
+                        simulateModel, SLOT(addPackage(PackageKit::Package *)));
+
+                // Create a Transaction dialog to don't upset the user
+                QPointer<KpkTransaction> reqFinder = new KpkTransaction(t, KpkTransaction::CloseOnFinish | KpkTransaction::Modal, this);
+                reqFinder->exec();
+                if (reqFinder->exitStatus() == KpkTransaction::Success) {
+                    if (simulateModel->rowCount(QModelIndex()) > 0) {
+                        QPointer<KpkRequirements> rq = new KpkRequirements(simulateModel, this);
+                        if (rq->exec() == QDialog::Accepted) {
+                            updatePackages();
+                        }
+                        delete rq;
+                    } else {
+                        updatePackages();
+                    }
+                }
+                delete reqFinder;
+        }
     } else {
         updatePackages();
     }
+    QTimer::singleShot(0, this, SLOT(checkEnableUpdateButton()));
 }
 
 void KpkUpdate::getUpdatesFinished(Transaction::ExitStatus status, uint runtime)
@@ -136,91 +153,112 @@ void KpkUpdate::getUpdatesFinished(Transaction::ExitStatus status, uint runtime)
     // If we just have one group let's expand it
     if (m_pkg_model_updates->rowCount() == 1) {
         packageView->expandAll();
-    }
-    checkEnableUpdateButton();
-}
+    } else if (m_pkg_model_updates->rowCount() == 2) {
+        int nonBlockedIndex = -1;
+        if (m_pkg_model_updates->data(m_pkg_model_updates->index(0,0),
+                                      KpkPackageModel::StateRole).toUInt()
+            == Package::StateBlocked) {
+            // We got a blocked update in index 0, so 1 is not blocked...
+            nonBlockedIndex = 1;
+        }
+        if (m_pkg_model_updates->data(m_pkg_model_updates->index(1,0),
+                                      KpkPackageModel::StateRole).toUInt()
+            == Package::StateBlocked) {
+            // We got a blocked update in index 1, so 0 is not blocked...
+            nonBlockedIndex = 0;
+        }
 
-void KpkUpdate::getDependsFinished(PackageKit::Transaction::ExitStatus status, uint runtime)
-{
-    Q_UNUSED(status)
-    Q_UNUSED(runtime)
-
-    if (status == Transaction::ExitSuccess) {
-        if (m_dependsPkgModel->rowCount(QModelIndex()) > 0) {
-            KpkRequirements *requimentD = new KpkRequirements(i18n("The following packages will also be installed as dependencies"), m_dependsPkgModel, this);
-            connect(requimentD, SIGNAL(okClicked()), this, SLOT(updatePackages()));
-            requimentD->show();
-        } else {
-            updatePackages();
+        if (nonBlockedIndex != -1) {
+            // we have a blocked update expand the non blocked one
+            packageView->expand(m_pkg_model_updates->index(nonBlockedIndex,0));
         }
     }
-
+    checkEnableUpdateButton();
 }
 
 void KpkUpdate::updatePackages()
 {
     QList<Package*> packages = m_pkg_model_updates->selectedPackages();
-    Client::instance()->setProxy(KProtocolManager::proxyFor("http"), KProtocolManager::proxyFor("ftp"));
 
-    if (Transaction *t = m_client->updatePackages(packages)) {
-        KpkTransaction *frm = new KpkTransaction(t, KpkTransaction::Modal | KpkTransaction::CloseOnFinish, this);
-        connect(frm, SIGNAL(kTransactionFinished(KpkTransaction::ExitStatus)),
-                this, SLOT(displayUpdates(KpkTransaction::ExitStatus)));
-        frm->show();
+    SET_PROXY
+    Transaction *t = m_client->updatePackages(true, packages);
+    if (t->error()) {
+        KMessageBox::sorry(this, KpkStrings::daemonError(t->error()));
     } else {
-        KMessageBox::sorry(this,
-                           i18n("You do not have the necessary privileges to perform this action."),
-                           i18n("Failed to update package lists"));
+        KpkTransaction *frm = new KpkTransaction(t, KpkTransaction::Modal | KpkTransaction::CloseOnFinish, this);
+        frm->setPackages(packages);
+        connect(frm, SIGNAL(kTransactionFinished(KpkTransaction::ExitStatus)),
+                this, SLOT(updatePackagesFinished(KpkTransaction::ExitStatus)));
+        frm->exec();
     }
 }
 
 void KpkUpdate::refresh()
 {
-    if ( Transaction *t = m_client->refreshCache(true) ) {
-        KpkTransaction *frm = new KpkTransaction(t, KpkTransaction::Modal | KpkTransaction::CloseOnFinish, this);
-        connect(frm, SIGNAL(kTransactionFinished(KpkTransaction::ExitStatus)),
-                 this, SLOT(displayUpdates(KpkTransaction::ExitStatus)));
-        frm->show();
+    SET_PROXY
+    Transaction *t = m_client->refreshCache(true);
+    if (t->error()) {
+        KMessageBox::sorry(this, KpkStrings::daemonError(t->error()));
     } else {
-        KMessageBox::sorry(this,
-                           i18n("You do not have the necessary privileges to perform this action."),
-                           i18n("Failed to refresh package lists"));
+        KpkTransaction *frm = new KpkTransaction(t, KpkTransaction::Modal | KpkTransaction::CloseOnFinish, this);
+        frm->show();
     }
 }
 
-void KpkUpdate::displayUpdates(KpkTransaction::ExitStatus status)
+void KpkUpdate::getUpdates()
 {
-    checkEnableUpdateButton();
-    if (status == KpkTransaction::Success) {
-        // contract to delete all update details widgets
-        pkg_delegate->contractAll();
-        // clears the model
-        m_pkg_model_updates->clear();
-        m_pkg_model_updates->uncheckAll();
-        m_updatesT = m_client->getUpdates();
+    // contract to delete all update details widgets
+    pkg_delegate->contractAll();
+    // clears the model
+    m_pkg_model_updates->clear();
+    m_pkg_model_updates->uncheckAll();
+    m_updatesT = m_client->getUpdates();
+    if (m_updatesT->error()) {
+        KMessageBox::sorry(this, KpkStrings::daemonError(m_updatesT->error()));
+    } else {
         transactionBar->addTransaction(m_updatesT);
         connect(m_updatesT, SIGNAL(package(PackageKit::Package *)),
                 m_pkg_model_updates, SLOT(addPackage(PackageKit::Package *)));
         connect(m_updatesT, SIGNAL(errorCode(PackageKit::Client::ErrorType, const QString &)),
                 this, SLOT(errorCode(PackageKit::Client::ErrorType, const QString &)));
         connect(m_updatesT, SIGNAL(finished(PackageKit::Transaction::ExitStatus, uint)),
-                this, SLOT(getUpdatesFinished(PackageKit::Transaction::ExitStatus, uint) ) );
-        // Clean the distribution upgrades area
-        QLayoutItem *child;
-        while ((child = verticalLayout->takeAt(0)) != 0) {
-            delete child->widget();
-            delete child;
-        }
-        distroUpgradesSA->hide();
-        line->hide();
-        // Check for distribution Upgrades
-        Transaction* t = m_client->getDistroUpgrades();
+                this, SLOT(getUpdatesFinished(PackageKit::Transaction::ExitStatus, uint) ));
+    }
+
+    // Clean the distribution upgrades area
+    QLayoutItem *child;
+    while ((child = verticalLayout->takeAt(0)) != 0) {
+        delete child->widget();
+        delete child;
+    }
+    distroUpgradesSA->hide();
+    line->hide();
+
+    // Check for distribution Upgrades
+    Transaction *t = m_client->getDistroUpgrades();
+    if (!t->error()) {
         transactionBar->addTransaction(t);
         connect(t, SIGNAL(distroUpgrade(PackageKit::Client::DistroUpgradeType, const QString &, const QString &)),
                 this, SLOT(distroUpgrade(PackageKit::Client::DistroUpgradeType, const QString &, const QString &)));
     }
 }
 
+void KpkUpdate::updatePackagesFinished(KpkTransaction::ExitStatus status)
+{
+    checkEnableUpdateButton();
+    KpkTransaction *trans = (KpkTransaction *) sender();
+    if (status == KpkTransaction::ReQueue) {
+        SET_PROXY
+        Transaction *t = m_client->updatePackages(trans->onlyTrusted(), trans->packages());
+        if (t->error()) {
+                KMessageBox::sorry(this, KpkStrings::daemonError(t->error()));
+                trans->deleteLater();
+        } else {
+                trans->setTransaction(t);
+        }
+    }
+}
+
 void KpkUpdate::on_refreshPB_clicked()
 {
     refresh();
