@@ -29,7 +29,6 @@
 #include "ui_KpkUpdate.h"
 
 class KpkPackageModel;
-class KpkSimplePackageModel;
 class KpkDelegate;
 class KProgressDialog;
 
@@ -56,10 +55,11 @@ private slots:
 
     void distroUpgrade(PackageKit::Client::DistroUpgradeType type, const QString &name, const QString &description);
 
-    void displayUpdates(KpkTransaction::ExitStatus status);
+    void getUpdates();
     void getUpdatesFinished(PackageKit::Transaction::ExitStatus status, uint runtime);
-    void getDependsFinished(PackageKit::Transaction::ExitStatus status, uint runtime);
+
     void updatePackages();
+    void updatePackagesFinished(KpkTransaction::ExitStatus status);
 
     void updateColumnsWidth(bool force = false);
     void on_packageView_pressed(const QModelIndex &index);
@@ -67,9 +67,9 @@ private slots:
     void checkEnableUpdateButton();
     void errorCode(PackageKit::Client::ErrorType error, const QString &details);
 
+
 private:
     KpkPackageModel *m_pkg_model_updates;
-    KpkSimplePackageModel *m_dependsPkgModel;
 
     KpkDelegate *pkg_delegate;
     Client *m_client;
