@@ -28,71 +28,118 @@ QString KpkStrings::status(PackageKit::Transaction::Status status)
 {
     switch (status) {
     case Transaction::UnknownStatus :
-        return i18nc("The transaction state", "Unknown state");
+        return i18nc("This is when the transaction status is not known",
+                     "Unknown state");
     case Transaction::StatusSetup :
-        return i18nc("The transaction state", "Waiting for service to start");
+        return i18nc("transaction state, the daemon is in the process of starting",
+                     "Waiting for service to start");
     case Transaction::StatusWait :
-        return i18nc("The transaction state", "Waiting for other tasks");
+        return i18nc("transaction state, the transaction is waiting for another to complete",
+                     "Waiting for other tasks");
     case Transaction::StatusRunning :
-        return i18nc("The transaction state", "Running task");
+        return i18nc("transaction state, just started",
+                     "Running task");
     case Transaction::StatusQuery :
-        return i18nc("The transaction state", "Querying");
+        return i18nc("transaction state, is querying data",
+                     "Querying");
     case Transaction::StatusInfo :
-        return i18nc("The transaction state", "Getting information");
+        return i18nc("transaction state, getting data from a server",
+                     "Getting information");
     case Transaction::StatusRemove :
-        return i18nc("The transaction state", "Removing packages");
+        return i18nc("transaction state, removing packages",
+                     "Removing packages");
     case Transaction::StatusDownload :
-        return i18nc("The transaction state", "Downloading packages");
+        return i18nc("transaction state, downloading package files",
+                     "Downloading packages");
     case Transaction::StatusInstall :
-        return i18nc("The transaction state", "Installing packages");
+        return i18nc("transaction state, installing packages",
+                     "Installing packages");
     case Transaction::StatusRefreshCache :
-        return i18nc("The transaction state", "Refreshing software list");
+        return i18nc("transaction state, refreshing internal lists",
+                     "Refreshing software list");
     case Transaction::StatusUpdate :
-        return i18nc("The transaction state", "Updating packages");
+        return i18nc("transaction state, installing updates",
+                     "Updating packages");
     case Transaction::StatusCleanup :
-        return i18nc("The transaction state", "Cleaning up packages");
+        return i18nc("transaction state, removing old packages, and cleaning config files",
+                     "Cleaning up packages");
     case Transaction::StatusObsolete :
-        return i18nc("The transaction state", "Obsoleting packages");
+        return i18nc("transaction state, obsoleting old packages",
+                     "Obsoleting packages");
     case Transaction::StatusDepResolve :
-        return i18nc("The transaction state", "Resolving dependencies");
+        return i18nc("transaction state, checking the transaction before we do it",
+                     "Resolving dependencies");
     case Transaction::StatusSigCheck :
-        return i18nc("The transaction state", "Checking signatures");
+        return i18nc("transaction state, checking if we have all the security keys for the operation",
+                     "Checking signatures");
     case Transaction::StatusRollback :
-        return i18nc("The transaction state", "Rolling back");
+        return i18nc("transaction state, when we return to a previous system state",
+                     "Rolling back");
     case Transaction::StatusTestCommit :
-        return i18nc("The transaction state", "Testing changes");
+        return i18nc("transaction state, when we're doing a test transaction",
+                     "Testing changes");
     case Transaction::StatusCommit :
-        return i18nc("The transaction state", "Committing changes");
+        return i18nc("transaction state, when we're writing to the system package database",
+                     "Committing changes");
     case Transaction::StatusRequest :
-        return i18nc("The transaction state", "Requesting data");
+        return i18nc("transaction state, requesting data from a server",
+                     "Requesting data");
     case Transaction::StatusFinished :
-        return i18nc("The transaction state", "Finished");
+        return i18nc("transaction state, all done!",
+                     "Finished");
     case Transaction::StatusCancel :
-        return i18nc("The transaction state", "Cancelling");
+        return i18nc("transaction state, in the process of cancelling",
+                     "Cancelling");
     case Transaction::StatusDownloadRepository :
-        return i18nc("The transaction state", "Downloading repository information");
+        return i18nc("transaction state, downloading metadata",
+                     "Downloading repository information");
     case Transaction::StatusDownloadPackagelist :
-        return i18nc("The transaction state", "Downloading list of packages");
+        return i18nc("transaction state, downloading metadata",
+                     "Downloading list of packages");
     case Transaction::StatusDownloadFilelist :
-        return i18nc("The transaction state", "Downloading file lists");
+        return i18nc("transaction state, downloading metadata",
+                     "Downloading file lists");
     case Transaction::StatusDownloadChangelog :
-        return i18nc("The transaction state", "Downloading lists of changes");
+        return i18nc("transaction state, downloading metadata",
+                     "Downloading lists of changes");
     case Transaction::StatusDownloadGroup :
-        return i18nc("The transaction state", "Downloading groups");
+        return i18nc("transaction state, downloading metadata",
+                     "Downloading groups");
     case Transaction::StatusDownloadUpdateinfo :
-        return i18nc("The transaction state", "Downloading update information");
+        return i18nc("transaction state, downloading metadata",
+                     "Downloading update information");
     case Transaction::StatusRepackaging :
-        return i18nc("The transaction state", "Repackaging files");
+        return i18nc("transaction state, repackaging delta files",
+                     "Repackaging files");
     case Transaction::StatusLoadingCache :
-        return i18nc("The transaction state", "Loading cache");
+        return i18nc("transaction state, loading databases",
+                     "Loading cache");
     case Transaction::StatusScanApplications :
-        return i18nc("The transaction state", "Scanning installed applications");
+        return i18nc("transaction state, scanning for running processes",
+                     "Scanning installed applications");
     case Transaction::StatusGeneratePackageList :
-        return i18nc("The transaction state", "Generating package lists");
+        return i18nc("transaction state, generating a list of packages installed on the system",
+                     "Generating package lists");
     case Transaction::StatusWaitingForLock :
-        return i18nc("The transaction state", "Waiting for package manager lock");
+        return i18nc("transaction state, when we're waiting for the native tools to exit",
+                     "Waiting for package manager lock");
+    case Transaction::StatusWaitingForAuth :
+        return i18nc("waiting for user to type in a password",
+                     "Waiting for authentication");
+    case Transaction::StatusScanProcessList :
+        return i18nc("we are updating the list of processes",
+                     "Updating the list of running applications");
+    case Transaction::StatusCheckExecutableFiles :
+        return i18nc("we are checking executable files in use",
+                     "Checking for applications currently in use");
+    case Transaction::StatusCheckLibraries :
+        return i18nc("we are checking for libraries in use",
+                     "Checking for libraries currently in use");
+    case Transaction::StatusCopyFiles :
+        return i18nc("we are copying package files to prepare to install",
+                     "Copying files");
     }
-    kDebug() << "status unrecognised: " << status;
+    kWarning() << "status unrecognised: " << status;
     return QString();
 }
 
@@ -112,7 +159,7 @@ QString KpkStrings::statusPast(PackageKit::Transaction::Status status)
     case Transaction::StatusObsolete:
         return i18nc("The action of the package, in past tense", "Obsoleted");
     default : // In this case we don't want to map all enums
-        kDebug() << "status unrecognised: " << status;
+        kWarning() << "status unrecognised: " << status;
         return QString();
     }
 }
@@ -182,8 +229,16 @@ QString KpkStrings::action(Client::Action action)
         return i18nc("The role of the transaction, in present tense", "Getting categories");
     case Client::ActionGetOldTransactions :
         return i18nc("The role of the transaction, in present tense", "Getting old transactions");
+    case Client::ActionSimulateInstallFiles :
+        return i18nc("The role of the transaction, in present tense", "Simulating the install of files");
+    case Client::ActionSimulateInstallPackages :
+        return i18nc("The role of the transaction, in present tense", "Simulating the install");
+    case Client::ActionSimulateRemovePackages :
+        return i18nc("The role of the transaction, in present tense", "Simulating the remove");
+    case Client::ActionSimulateUpdatePackages :
+        return i18nc("The role of the transaction, in present tense", "Simulating the update");
     }
-    kDebug() << "action unrecognised: " << action;
+    kWarning() << "action unrecognised: " << action;
     return QString();
 }
 
@@ -252,8 +307,16 @@ QString KpkStrings::actionPast(Client::Action action)
         return i18nc("The role of the transaction, in past tense", "Got categories");
     case Client::ActionGetOldTransactions :
         return i18nc("The role of the transaction, in past tense", "Got old transactions");
+    case Client::ActionSimulateInstallFiles :
+        return i18nc("The role of the transaction, in past tense", "Simulated the install of files");
+    case Client::ActionSimulateInstallPackages :
+        return i18nc("The role of the transaction, in past tense", "Simulated the install");
+    case Client::ActionSimulateRemovePackages :
+        return i18nc("The role of the transaction, in past tense", "Simulated the remove");
+    case Client::ActionSimulateUpdatePackages :
+        return i18nc("The role of the transaction, in past tense", "Simulated the update");
     }
-    kDebug() << "action unrecognised: " << action;
+    kWarning() << "action unrecognised: " << action;
     return QString();
 }
 
@@ -315,7 +378,7 @@ QString KpkStrings::error(PackageKit::Client::ErrorType error)
     case Client::ErrorPackageConflicts :
         return i18n("Packages are not compatible");
     case Client::ErrorRepoNotAvailable :
-        return i18n("Problem connecting to a software source");
+        return i18n("Problem connecting to a software origin");
     case Client::ErrorFailedInitialization :
         return i18n("Failed to initialize");
     case Client::ErrorFailedFinalise :
@@ -354,10 +417,34 @@ QString KpkStrings::error(PackageKit::Client::ErrorType error)
         return i18n("No space is left on the disk");
     case Client::ErrorMediaChangeRequired :
         return i18n("A media change is required");
+    case Client::ErrorNotAuthorized :
+        return i18n("Authorization failed");
+    case Client::ErrorUpdateNotFound :
+        return i18n("Update not found");
+    case Client::ErrorCannotInstallRepoUnsigned :
+        return i18n("Cannot install from untrusted origin");
+    case Client::ErrorCannotUpdateRepoUnsigned :
+        return i18n("Cannot update from untrusted origin");
+    case Client::ErrorCannotGetFilelist :
+        return i18n("Cannot get the file list");
+    case Client::ErrorCannotGetRequires :
+        return i18n("Cannot get package requires");
+    case Client::ErrorCannotDisableRepository :
+        return i18n("Cannot disable origin");
+    case Client::ErrorRestrictedDownload :
+        return i18n("The download failed");
+    case Client::ErrorPackageFailedToConfigure :
+        return i18n("Package failed to configure");
+    case Client::ErrorPackageFailedToBuild :
+        return i18n("Package failed to build");
+    case Client::ErrorPackageFailedToInstall :
+        return i18n("Package failed to install");
+    case Client::ErrorPackageFailedToRemove :
+        return i18n("Package failed to be removed");
     case Client::UnknownErrorType :
         return i18n("Unknown error");
     }
-    kDebug() << "error unrecognised: " << error;
+    kWarning() << "error unrecognised: " << error;
     return QString();
 }
 
@@ -382,12 +469,12 @@ QString KpkStrings::errorMessage(PackageKit::Client::ErrorType error)
         return i18n("A problem that we were not expecting has occurred.\n"
                     "Please report this bug with the error description.");
     case Client::ErrorGpgFailure :
-        return i18n("A security trust relationship could not be made with the software source.\n"
+        return i18n("A security trust relationship could not be made with the software origin.\n"
                     "Please check your software signature settings.");
     case Client::ErrorPackageNotInstalled :
         return i18n("The package that is trying to be removed or updated is not already installed.");
     case Client::ErrorPackageNotFound :
-        return i18n("The package that is being modified was not found on your system or in any software source.");
+        return i18n("The package that is being modified was not found on your system or in any software origin.");
     case Client::ErrorPackageAlreadyInstalled :
         return i18n("The package that is trying to be installed is already installed.");
     case Client::ErrorPackageDownloadFailed :
@@ -399,7 +486,7 @@ QString KpkStrings::errorMessage(PackageKit::Client::ErrorType error)
     case Client::ErrorGroupListInvalid :
         return i18n("The group list could not be loaded.\n"
                     "Refreshing your cache may help, although this is normally a software "
-                    "source error.");
+                    "origin error.");
     case Client::ErrorDepResolutionFailed :
         return i18n("A package dependency could not be found.\n"
                     "More information is available in the detailed report.");
@@ -412,8 +499,8 @@ QString KpkStrings::errorMessage(PackageKit::Client::ErrorType error)
         return i18n("An error occurred while running the transaction.\n"
                     "More information is available in the detailed report.");
     case Client::ErrorRepoNotFound :
-        return i18n("The remote software source name was not found.\n"
-                    "You may need to enable an item in Software Sources.");
+        return i18n("The remote software origin name was not found.\n"
+                    "You may need to enable an item in Software Origins.");
     case Client::ErrorCannotRemoveSystemPackage :
         return i18n("Removing a protected system package is not allowed.");
     case Client::ErrorTransactionCancelled :
@@ -434,12 +521,12 @@ QString KpkStrings::errorMessage(PackageKit::Client::ErrorType error)
                     "To use this software you have to accept the license.");
     case Client::ErrorFileConflicts :
         return i18n("Two packages provide the same file.\n"
-                    "This is usually due to mixing packages for different software sources.");
+                    "This is usually due to mixing packages for different software origins.");
     case Client::ErrorPackageConflicts :
         return i18n("Multiple packages exist that are not compatible with each other.\n"
-                    "This is usually due to mixing packages from different software sources.");
+                    "This is usually due to mixing packages from different software origins.");
     case Client::ErrorRepoNotAvailable :
-        return i18n("There was a (possibly temporary) problem connecting to a software source.\n"
+        return i18n("There was a (possibly temporary) problem connecting to a software origins.\n"
                     "Please check the detailed error for further details.");
     case Client::ErrorFailedInitialization :
         return i18n("Failed to initialize packaging backend.\n"
@@ -477,10 +564,10 @@ QString KpkStrings::errorMessage(PackageKit::Client::ErrorType error)
         return i18n("The specified file could not be found on the system.\n"
                     "Check that the file still exists and has not been deleted.");
     case Client::ErrorNoMoreMirrorsToTry :
-        return i18n("Required data could not be found on any of the configured software sources.\n"
+        return i18n("Required data could not be found on any of the configured software origins.\n"
                     "There were no more download mirrors that could be tried.");
     case Client::ErrorNoDistroUpgradeData :
-        return i18n("Required upgrade data could not be found in any of the configured software sources.\n"
+        return i18n("Required upgrade data could not be found in any of the configured software origins.\n"
                     "The list of distribution upgrades will be unavailable.");
     case Client::ErrorIncompatibleArchitecture :
         return i18n("The package that is trying to be installed is incompatible with this system.");
@@ -489,11 +576,42 @@ QString KpkStrings::errorMessage(PackageKit::Client::ErrorType error)
                     "Free some space on the system disk to perform this operation.");
     case Client::ErrorMediaChangeRequired :
         return i18n("Additional media is required to complete the transaction.");
+    case Client::ErrorNotAuthorized :
+        return i18n("You have failed to provide correct authentication.\n"
+                    "Please check any passwords or account settings.");
+    case Client::ErrorUpdateNotFound :
+        return i18n("The specified update could not be found.\n"
+                    "It could have already been installed or no longer available on the remote server.");
+    case Client::ErrorCannotInstallRepoUnsigned :
+        return i18n("The package could not be installed from untrusted origin.");
+    case Client::ErrorCannotUpdateRepoUnsigned :
+        return i18n("The package could not be updated from untrusted origin.");
+    case Client::ErrorCannotGetFilelist :
+        return i18n("The file list is not available for this package.");
+    case Client::ErrorCannotGetRequires :
+        return i18n("The information about what requires this package could not be obtained.");
+    case Client::ErrorCannotDisableRepository :
+        return i18n("The specified software origin could not be disabled.");
+    case Client::ErrorRestrictedDownload :
+        return i18n("The download could not be done automatically and should be done manually.\n"
+                    "More information is available in the detailed report.");
+    case Client::ErrorPackageFailedToConfigure :
+        return i18n("One of the selected packages failed to configure correctly.\n"
+                    "More information is available in the detailed report.");
+    case Client::ErrorPackageFailedToBuild :
+        return i18n("One of the selected packages failed to build correctly.\n"
+                    "More information is available in the detailed report.");
+    case Client::ErrorPackageFailedToInstall :
+        return i18n("One of the selected packages failed to install correctly.\n"
+                    "More information is available in the detailed report.");
+    case Client::ErrorPackageFailedToRemove :
+        return i18n("One of the selected packages failed to be removed correctly.\n"
+                    "More information is available in the detailed report.");
     case Client::UnknownErrorType :
         return i18n("Unknown error, please report a bug.\n"
                     "More information is available in the detailed report.");
     }
-    kDebug() << "error unrecognised: " << error;
+    kWarning() << "error unrecognised: " << error;
     return QString();
 }
 
@@ -571,7 +689,7 @@ QString KpkStrings::groups(Client::Group group)
     case Client::UnknownGroup :
         return i18nc("The group type", "Unknown group");
     }
-    kDebug() << "group unrecognised: " << group;
+    kWarning() << "group unrecognised: " << group;
     return QString();
 }
 
@@ -601,7 +719,7 @@ QString KpkStrings::info(Package::State state)
     case Package::UnknownState :
         return i18nc("The type of update", "Unknown update");
     default : // In this case we don't want to map all enums
-        kDebug() << "info unrecognised: " << state;
+        kWarning() << "info unrecognised: " << state;
         return QString();
     }
 }
@@ -628,7 +746,7 @@ QString KpkStrings::infoUpdate(Package::State state, int number)
     case Package::StateAvailable :
         return i18np("1 available package", "%1 available packages", number);
     default : // In this case we don't want to map all enums
-        kDebug() << "update info unrecognised: " << state;
+        kWarning() << "update info unrecognised: " << state;
         return i18np("1 unknown update", "%1 unknown updates", number);
     }
 }
@@ -658,7 +776,7 @@ QString KpkStrings::infoUpdate(Package::State state, int updates, int selected)
             return i18np("1 available package selected to be installed",
                          "%1 available packages selected to be installed", updates);
         default : // In this case we don't want to map all enums
-            kDebug() << "update info unrecognised: " << state;
+            kWarning() << "update info unrecognised: " << state;
             return i18np("1 unknown update", "%1 unknown updates", updates);
         }
     } else if (selected == 0) {
@@ -686,7 +804,7 @@ QString KpkStrings::infoUpdate(Package::State state, int updates, int selected)
         case Package::StateAvailable :
             return i18np("%1 available package", "%1 available packages, %2 selected to be installed", updates, selected);
         default : // In this case we don't want to map all enums
-            kDebug() << "update info unrecognised: " << state;
+            kWarning() << "update info unrecognised: " << state;
             return i18np("%1 unknown update", "%1 unknown updates", updates);
         }
     }
@@ -703,10 +821,15 @@ QString KpkStrings::restartTypeFuture(Client::RestartType value)
         return i18n("You will be required to log out and back in");
     case Client::RestartSystem :
         return i18n("A restart will be required");
+    case Client::RestartSecuritySession :
+        return i18n("You will be required to log out and back in due to a security update.");
+    case Client::RestartSecuritySystem :
+        return i18n("A restart will be required due to a security update.");
     case Client::UnknownRestartType :
+        kWarning() << "restartTypeFuture(Client::UnknownRestartType)";
         return QString();
     }
-    kDebug() << "restart unrecognised: " << value;
+    kWarning() << "restart unrecognised: " << value;
     return QString();
 }
 
@@ -721,10 +844,15 @@ QString KpkStrings::restartType(Client::RestartType value)
         return i18n("You need to log out and log back in");
     case Client::RestartApplication :
         return i18n("You need to restart the application");
+    case Client::RestartSecuritySession :
+        return i18n("You need to log out and log back in to remain secure.");
+    case Client::RestartSecuritySystem :
+        return i18n("A restart is required to remain secure.");
     case Client::UnknownRestartType :
+        kWarning() << "restartType(Client::UnknownRestartType)";
         return QString();
     }
-    kDebug() << "restart unrecognised: " << value;
+    kWarning() << "restart unrecognised: " << value;
     return QString();
 }
 
@@ -738,9 +866,10 @@ QString KpkStrings::updateState(Client::UpdateState value)
     case Client::UpdateTesting :
         return i18n("Testing");
     case Client::UnknownUpdateState :
+        kWarning() << "updateState(Client::UnknownUpdateState)";
         return QString();
     }
-    kDebug() << "value unrecognised: " << value;
+    kWarning() << "value unrecognised: " << value;
     return QString();
 }
 
@@ -756,7 +885,7 @@ QString KpkStrings::mediaMessage(Transaction::MediaType value, const QString &te
     case Transaction::UnknownMediaType :
         return i18n("Please insert the medium labeled '%1', and press continue.", text);
     }
-    kDebug() << "value unrecognised: " << value;
+    kWarning() << "value unrecognised: " << value;
     return i18n("Please insert the medium labeled '%1', and press continue.", text);
 }
 
@@ -787,9 +916,44 @@ QString KpkStrings::message(PackageKit::Client::MessageType value)
         return i18n("Configuration files were changed");
     case Client::MessagePackageAlreadyInstalled :
         return i18n("Package is already installed");
+    case Client::MessageAutoremoveIgnored :
+        return i18n("Automatic cleanup is being ignored");
+    case Client::MessageRepoMetadataDownloadFailed :
+        return i18n("Software source download failed");
     case Client::UnknownMessageType :
+        kWarning() << "message(Client::UnknownMessageType)";
         return QString();
     }
-    kDebug() << "value unrecognised: " << value;
+    kWarning() << "value unrecognised: " << value;
     return QString();
 }
+
+QString KpkStrings::daemonError(PackageKit::Client::DaemonError value)
+{
+    switch (value) {
+    case Client::ErrorFailedAuth :
+        return i18n("You do not have the necessary privileges to perform this action.");
+    case Client::ErrorNoTid :
+        return i18n("Could not get a transaction id from packagekitd.");
+    case Client::ErrorAlreadyTid :
+        return i18n("Cannot connect to this transaction id.");
+    case Client::ErrorRoleUnkown :
+        return i18n("This action is unknown.");
+    case Client::ErrorCannotStartDaemon :
+        return i18n("The packagekitd service could not be started.");
+    case Client::ErrorInvalidInput :
+        return i18n("The query is not valid.");
+    case Client::ErrorInvalidFile :
+        return i18n("The file is not valid.");
+    case Client::ErrorFunctionNotSupported :
+        return i18n("This function is not yet supported.");
+    case Client::ErrorDaemonUnreachable :
+        return i18n("Could not talk to packagekitd.");
+    case Client::NoError :
+    case Client::ErrorFailed :
+    case Client::UnkownError :
+        return i18n("An unknown error happened.");
+    }
+    kWarning() << "value unrecognised: " << value;
+    return i18n("An unknown error happened.");
+}
