@@ -46,6 +46,9 @@ public:
     QString tid;
     bool showDetails;
     bool finished;
+    bool allowDeps;
+    bool onlyTrusted;
+    QList<Package*> packages;
 };
 
 KpkTransaction::KpkTransaction(Transaction *trans, Behaviors flags, QWidget *parent)
@@ -54,24 +57,37 @@ KpkTransaction::KpkTransaction(Transaction *trans, Behaviors flags, QWidget *par
    m_handlingActionRequired(false),
    m_showingError(false),
    m_flags(flags),
+   m_exitStatus(Success),
+   m_status(Transaction::UnknownStatus),
    d(new KpkTransactionPrivate)
 {
     d->ui.setupUi(mainWidget());
     d->finished = true; // for sanity we are finished till some transaction is set
+    d->onlyTrusted = true; // for sanity we are trusted till an error is given and the user accepts
 
     // Set Cancel and custom button hide
     setButtons(KDialog::Cancel | KDialog::User1 | KDialog::Details);
+    enableButton(KDialog::Details, false);
     setButtonText(KDialog::User1, i18n("Hide"));
     setButtonToolTip(KDialog::User1, i18n("Allows you to hide the window whilst keeping the transaction task running."));
     setEscapeButton(KDialog::User1);
     enableButtonCancel(false);
     setDetailsWidget(d->ui.detailGroup);
-    setDetailsWidgetVisible(false);
     KConfig config("KPackageKit");
     KConfigGroup transactionGroup(&config, "Transaction");
     d->showDetails = transactionGroup.readEntry("ShowDetails", false);
+    setDetailsWidgetVisible(d->showDetails);
+    d->ui.detailGroup->setVisible(d->showDetails);
 
-    enableButton(KDialog::Details, false);
+    // This MUST come after setDetailsWidgetVisible since
+    // it keeps ajusting the size (which sucks btw)
+    // This doesn't work, KDialog resizes when the details
+    // button is clicked, maybe it should save the size
+    // before showing the details then when hiding it it would
+    // go back to the first size.
+//     setMinimumSize(QSize(400,120));
+//     KConfigGroup transactionDialog(&config, "TransactionDialog");
+//     restoreDialogSize(transactionDialog);
 
     if (m_flags & Modal) {
         setWindowModality(Qt::WindowModal);
@@ -79,6 +95,8 @@ KpkTransaction::KpkTransaction(Transaction *trans, Behaviors flags, QWidget *par
 
     // We need to track when the user close the dialog using the [X] button
     connect(this, SIGNAL(finished()), SLOT(finishedDialog()));
+    connect(this, SIGNAL(kTransactionFinished(KpkTransaction::ExitStatus)),
+            SLOT(setExitStatus(KpkTransaction::ExitStatus)));
 
     // after ALL set, lets set the transaction
     setTransaction(m_trans);
@@ -86,11 +104,13 @@ KpkTransaction::KpkTransaction(Transaction *trans, Behaviors flags, QWidget *par
 
 KpkTransaction::~KpkTransaction()
 {
+    KConfig config("KPackageKit");
     if (isButtonEnabled(KDialog::Details)) {
-        KConfig config("KPackageKit");
         KConfigGroup transactionGroup(&config, "Transaction");
         transactionGroup.writeEntry("ShowDetails", isDetailsWidgetVisible());
     }
+//     KConfigGroup transactionDialog(&config, "TransactionDialog");
+//     saveDialogSize(transactionDialog);
 
     // DO NOT disconnect the transaction here,
     // it might not exist when this happen
@@ -102,6 +122,31 @@ QString KpkTransaction::tid() const
     return d->tid;
 }
 
+bool KpkTransaction::allowDeps() const
+{
+    return d->allowDeps;
+}
+
+bool KpkTransaction::onlyTrusted() const
+{
+    return d->onlyTrusted;
+}
+
+QList<Package*> KpkTransaction::packages() const
+{
+    return d->packages;
+}
+
+void KpkTransaction::setAllowDeps(bool allowDeps)
+{
+    d->allowDeps = allowDeps;
+}
+
+void KpkTransaction::setPackages(QList<Package*> packages)
+{
+    d->packages = packages;
+}
+
 void KpkTransaction::setTransaction(Transaction *trans)
 {
     m_trans = trans;
@@ -109,27 +154,28 @@ void KpkTransaction::setTransaction(Transaction *trans)
     d->finished = false;
 
     // sets the action icon to be the window icon
-    setWindowIcon(KpkIcons::actionIcon(m_trans->role().action));
+    setWindowIcon(KpkIcons::actionIcon(m_trans->role()));
     // Sets the kind of transaction
-    setCaption(KpkStrings::action(m_trans->role().action));
+    setCaption(KpkStrings::action(m_trans->role()));
     // check to see if we can cancel
     enableButtonCancel(m_trans->allowCancel());
     // clears the package label
     d->ui.packageL->clear();
-    d->ui.descriptionL->clear();
+    d->ui.descriptionL->setText(QString());
     // Now sets the last package
     currPackage(m_trans->lastPackage());
     // sets the current progress
-    progressChanged(m_trans->progress());
+    updateUi();
     // sets the current status
-    if (m_trans->status() == Transaction::UnknownStatus) {
-       statusChanged(Transaction::StatusSetup);
-    } else {
-       statusChanged(m_trans->status());
-    }
+    // TODO
+//     if (m_trans->status() == Transaction::UnknownStatus) {
+//        statusChanged(Transaction::StatusSetup);
+//     } else {
+//        statusChanged(m_trans->status());
+//     }
 
-    if (m_trans->role().action == Client::ActionRefreshCache ||
-        m_trans->role().action == Client::ActionWhatProvides) {
+    if (m_trans->role() == Client::ActionRefreshCache ||
+        m_trans->role() == Client::ActionWhatProvides) {
         d->ui.packageL->hide();
         d->ui.descriptionL->hide();
     } else {
@@ -137,39 +183,58 @@ void KpkTransaction::setTransaction(Transaction *trans)
         d->ui.descriptionL->show();
     }
 
+    // DISCONNECT ALL THESE SIGNALS BEFORE CLOSING
     connect(m_trans, SIGNAL(package(PackageKit::Package *)),
             this, SLOT(currPackage(PackageKit::Package *)));
     connect(m_trans, SIGNAL(finished(PackageKit::Transaction::ExitStatus, uint)),
             this, SLOT(finished(PackageKit::Transaction::ExitStatus, uint)));
-    connect(m_trans, SIGNAL(allowCancelChanged(bool)),
-            this, SLOT(enableButtonCancel(bool)));
     connect(m_trans, SIGNAL(errorCode(PackageKit::Client::ErrorType, const QString &)),
             this, SLOT(errorCode(PackageKit::Client::ErrorType, const QString &)));
-    connect(m_trans, SIGNAL(progressChanged(PackageKit::Transaction::ProgressInfo)),
-            this, SLOT(progressChanged(PackageKit::Transaction::ProgressInfo)));
-    connect(m_trans, SIGNAL(statusChanged(PackageKit::Transaction::Status)),
-            this, SLOT(statusChanged(PackageKit::Transaction::Status)));
+    connect(m_trans, SIGNAL(changed()),
+            this, SLOT(updateUi()));
     connect(m_trans, SIGNAL(eulaRequired(PackageKit::Client::EulaInfo)),
             this, SLOT(eulaRequired(PackageKit::Client::EulaInfo)));
     connect(m_trans, SIGNAL(mediaChangeRequired(PackageKit::Transaction::MediaType, const QString &, const QString &)),
             this, SLOT(mediaChangeRequired(PackageKit::Transaction::MediaType, const QString &, const QString &)));
     connect(m_trans, SIGNAL(repoSignatureRequired(PackageKit::Client::SignatureInfo)),
             this, SLOT(repoSignatureRequired(PackageKit::Client::SignatureInfo)));
+    // DISCONNECT ALL THESE SIGNALS BEFORE CLOSING
 }
 
-void KpkTransaction::progressChanged(PackageKit::Transaction::ProgressInfo info)
+void KpkTransaction::unsetTransaction()
 {
-    if (info.percentage && info.percentage <= 100) {
+    disconnect(m_trans, SIGNAL(package(PackageKit::Package *)),
+               this, SLOT(currPackage(PackageKit::Package *)));
+    disconnect(m_trans, SIGNAL(finished(PackageKit::Transaction::ExitStatus, uint)),
+               this, SLOT(finished(PackageKit::Transaction::ExitStatus, uint)));
+    disconnect(m_trans, SIGNAL(errorCode(PackageKit::Client::ErrorType, const QString &)),
+               this, SLOT(errorCode(PackageKit::Client::ErrorType, const QString &)));
+    disconnect(m_trans, SIGNAL(changed()),
+               this, SLOT(updateUi()));
+    disconnect(m_trans, SIGNAL(eulaRequired(PackageKit::Client::EulaInfo)),
+               this, SLOT(eulaRequired(PackageKit::Client::EulaInfo)));
+    disconnect(m_trans, SIGNAL(mediaChangeRequired(PackageKit::Transaction::MediaType,
+                                                   const QString &, const QString &)),
+               this, SLOT(mediaChangeRequired(PackageKit::Transaction::MediaType, const QString &, const QString &)));
+    disconnect(m_trans, SIGNAL(repoSignatureRequired(PackageKit::Client::SignatureInfo)),
+               this, SLOT(repoSignatureRequired(PackageKit::Client::SignatureInfo)));
+}
+
+void KpkTransaction::updateUi()
+{
+    uint percentage = m_trans->percentage();
+    uint subpercentage = m_trans->subpercentage();
+    if (percentage && percentage <= 100) {
         d->ui.progressBar->setMaximum(100);
-        d->ui.progressBar->setValue(info.percentage);
+        d->ui.progressBar->setValue(percentage);
     } else if (d->ui.progressBar->maximum() != 0) {
         d->ui.progressBar->setMaximum(0);
         d->ui.progressBar->reset();
     }
 
-    if (info.subpercentage && info.subpercentage <= 100) {
+    if (subpercentage && subpercentage <= 100) {
         d->ui.subprogressBar->setMaximum(100);
-        d->ui.subprogressBar->setValue(info.subpercentage);
+        d->ui.subprogressBar->setValue(subpercentage);
     // Check if we didn't already set the maximum as this
     // causes a weird behavior when we keep reseting
     } else if (d->ui.subprogressBar->maximum() != 0) {
@@ -177,7 +242,34 @@ void KpkTransaction::progressChanged(PackageKit::Transaction::ProgressInfo info)
         d->ui.subprogressBar->reset();
     }
 
-    d->ui.progressBar->setRemaining(info.remaining);
+    d->ui.progressBar->setRemaining(m_trans->remainingTime());
+
+    // Status
+    Transaction::Status status = m_trans->status();
+    if (m_status != status) {
+        m_status = status;
+        d->ui.currentL->setText(KpkStrings::status(status));
+
+        QMovie *movie;
+        // Grab the right icon name
+        QString icon(KpkIcons::statusAnimation(status));
+        movie = KIconLoader::global()->loadMovie(icon,
+                                                KIconLoader::NoGroup,
+                                                48,
+                                                this);
+        if (movie) {
+            // If the movie is set we KIconLoader it,
+            // set it and start
+            d->ui.label->setMovie(movie);
+            movie->start();
+        } else {
+            // Else it's probably a static icon so try to load
+            d->ui.label->setPixmap(KpkIcons::getIcon(icon).pixmap(48,48));
+        }
+    }
+
+    // Allow cancel
+    enableButtonCancel(m_trans->allowCancel());
 }
 
 void KpkTransaction::currPackage(Package *p)
@@ -190,11 +282,11 @@ void KpkTransaction::currPackage(Package *p)
         d->ui.packageL->setText(packageText);
         d->ui.descriptionL->setText(p->summary());
         enableButton(KDialog::Details, true);
-        setDetailsWidgetVisible(d->showDetails);
     } else {
         d->ui.packageL->clear();
-        d->ui.descriptionL->clear();
+        d->ui.descriptionL->setText(QString());
         enableButton(KDialog::Details, false);
+        setDetailsWidgetVisible(false);
     }
 }
 
@@ -207,16 +299,17 @@ void KpkTransaction::finishedDialog()
         // transaction receives some error we can display them
         QDBusMessage message;
         message = QDBusMessage::createMethodCall("org.kde.KPackageKitSmartIcon",
-                                                    "/",
-                                                    "org.kde.KPackageKitSmartIcon",
-                                                    QLatin1String("WatchTransaction"));
+                                                 "/",
+                                                 "org.kde.KPackageKitSmartIcon",
+                                                 QLatin1String("WatchTransaction"));
         message << qVariantFromValue(m_trans->tid());
         QDBusMessage reply = QDBusConnection::sessionBus().call(message);
         if (reply.type() != QDBusMessage::ReplyMessage) {
             kWarning() << "Message did not receive a reply";
         }
         // Always disconnect BEFORE emitting finished
-        m_trans->disconnect();
+        unsetTransaction();
+
         emit kTransactionFinished(Success);
     }
 }
@@ -237,36 +330,32 @@ void KpkTransaction::slotButtonClicked(int button)
     case KDialog::Close :
         kDebug() << "KDialog::Close";
         // Always disconnect BEFORE emitting finished
-        m_trans->disconnect();
+        unsetTransaction();
         emit kTransactionFinished(Cancelled);
         done(KDialog::Close);
         break;
     case KDialog::Details :
         d->showDetails = !d->showDetails;
+//         d->ui.detailGroup->setVisible(d->showDetails);
+//         break;
     default : // Should be only details
         KDialog::slotButtonClicked(button);
     }
 }
 
-void KpkTransaction::statusChanged(PackageKit::Transaction::Status status)
-{
-    d->ui.currentL->setText(KpkStrings::status(status));
+// Return value: if the error code suggests to try with only_trusted %FALSE
 
-    QMovie *movie;
-    // Grab the right icon name
-    QString icon(KpkIcons::statusAnimation(status));
-    movie = KIconLoader::global()->loadMovie(icon,
-                                             KIconLoader::NoGroup,
-                                             48,
-                                             this);
-    if (movie) {
-        // If the movie is set we KIconLoader it,
-        // set it and start
-        d->ui.label->setMovie(movie);
-        movie->start();
-    } else {
-        // Else it's probably a static icon so try to load
-        d->ui.label->setPixmap(KpkIcons::getIcon(icon).pixmap(48,48));
+static bool untrustedIsNeed(PackageKit::Client::ErrorType error)
+{
+    switch (error) {
+    case Client::ErrorGpgFailure:
+    case Client::ErrorBadGpgSignature:
+    case Client::ErrorMissingGpgSignature:
+    case Client::ErrorCannotInstallRepoUnsigned:
+    case Client::ErrorCannotUpdateRepoUnsigned:
+        return true;
+    default:
+        return false;
     }
 }
 
@@ -278,16 +367,17 @@ void KpkTransaction::errorCode(PackageKit::Client::ErrorType error, const QStrin
         return;
     }
 
-    if (error == Client::ErrorMissingGpgSignature) {
+    if (untrustedIsNeed(error)) {
         kDebug() << "Missing GPG!";
         m_handlingActionRequired = true;
         int ret = KMessageBox::warningYesNo(this,
-                                            details +
-                                            i18n("<br />Installing unsigned packages can compromise your system, "
+                                            i18n("You are about to install unsigned packages can compromise your system, "
                                             "as it is impossible to verify if the software came from a trusted "
-                                            "source. Are you sure you want to continue installation?"),
+                                            "source.\n Are you sure you want to continue installation?"),
                                             i18n("Installing unsigned software"));
         if (ret == KMessageBox::Yes) {
+            // Set only trusted to false, to do as the user asked
+            d->onlyTrusted = false;
             emit kTransactionFinished(ReQueue);
             kDebug() << "Asking for a re-queue";
         } else {
@@ -295,12 +385,12 @@ void KpkTransaction::errorCode(PackageKit::Client::ErrorType error, const QStrin
             if (m_flags & CloseOnFinish)
                 done(QDialog::Rejected);
         }
+        m_handlingActionRequired = false;
         return;
     }
 
     // check to see if we are already handlying these errors
-    if (error == Client::ErrorGpgFailure ||
-        error == Client::ErrorNoLicenseAgreement ||
+    if (error == Client::ErrorNoLicenseAgreement ||
         error == Client::ErrorMediaChangeRequired)
     {
         if (m_handlingActionRequired) {
@@ -425,6 +515,7 @@ void KpkTransaction::finished(PackageKit::Transaction::ExitStatus status, uint r
     case Transaction::ExitKeyRequired :
     case Transaction::ExitEulaRequired :
     case Transaction::ExitMediaChangeRequired :
+    case Transaction::ExitNeedUntrusted :
         kDebug() << "finished KeyRequired or EulaRequired: " << status;
         d->ui.currentL->setText(KpkStrings::status(Transaction::StatusSetup));
         if (!m_handlingActionRequired) {
@@ -446,4 +537,14 @@ void KpkTransaction::finished(PackageKit::Transaction::ExitStatus status, uint r
     }
 }
 
+KpkTransaction::ExitStatus KpkTransaction::exitStatus() const
+{
+    return m_exitStatus;
+}
+
+void KpkTransaction::setExitStatus(KpkTransaction::ExitStatus status)
+{
+    m_exitStatus = status;
+}
+
 #include "KpkTransaction.moc"
