@@ -48,6 +48,12 @@ public:
     // of Transaction, instead compare the tid with the tids from
     // Client::getTransaction(), to avoid deleted pointers.
     QString tid() const;
+    bool allowDeps() const;
+    bool onlyTrusted() const;
+    QList<Package*> packages() const;
+
+    void setAllowDeps(bool allowDeps);
+    void setPackages(QList<Package*> packages);
 
     typedef enum {
         Success,
@@ -56,27 +62,34 @@ public:
         ReQueue
     } ExitStatus;
 
+    KpkTransaction::ExitStatus exitStatus() const;
+
 signals:
     void kTransactionFinished(KpkTransaction::ExitStatus status);
 
 private:
+    void unsetTransaction();
+
     Transaction *m_trans;
     bool m_handlingActionRequired;
     bool m_showingError; //This might replace the above
     Behaviors m_flags;
-    KpkTransactionPrivate* d;
+    ExitStatus m_exitStatus;
+    Transaction::Status m_status;
+    KpkTransactionPrivate *d;
 
 private slots:
     void finishedDialog();
     void finished(PackageKit::Transaction::ExitStatus status, uint runtime);
     void errorCode(PackageKit::Client::ErrorType error, const QString &details);
-    void statusChanged(PackageKit::Transaction::Status status);
     void currPackage(PackageKit::Package *);
-    void progressChanged(PackageKit::Transaction::ProgressInfo info);
+    void updateUi();
     void eulaRequired(PackageKit::Client::EulaInfo info);
     void mediaChangeRequired(PackageKit::Transaction::MediaType type, const QString &id, const QString &text);
     void repoSignatureRequired(PackageKit::Client::SignatureInfo info);
 
+    void setExitStatus(KpkTransaction::ExitStatus status);
+
 protected slots:
     virtual void slotButtonClicked(int button);
 };
